@@ -235,6 +235,76 @@ class TestJSONResourceStore(test_monolingual.TestMonolingualStore):
         assert str(unit) == expected.strip()
         assert bytes(store).decode() == expected
 
+    def test_add_list_like(self):
+        store = self.StoreClass()
+
+        unit = self.StoreClass.UnitClass("source")
+        unit.setid("[0]")
+        store.addunit(unit)
+
+        unit = self.StoreClass.UnitClass("source2")
+        unit.setid("key")
+        store.addunit(unit)
+
+        assert (
+            bytes(store).decode()
+            == """{
+    "[0]": "source",
+    "key": "source2"
+}
+"""
+        )
+        unit.setid("[1]")
+        assert (
+            bytes(store).decode()
+            == """{
+    "[0]": "source",
+    "[1]": "source2"
+}
+"""
+        )
+
+    def test_add_blank(self):
+        expected = """{
+    "simple.key": "source"
+}
+"""
+        store = self.StoreClass()
+        store.parse("true")
+
+        unit = self.StoreClass.UnitClass(
+            "source",
+        )
+        assert str(unit) != expected.strip()
+        unit.setid("simple.key")
+        store.addunit(unit)
+
+        assert str(unit) == expected.strip()
+        assert bytes(store).decode() == expected
+
+    def test_types(self):
+        store = self.StoreClass()
+        store.parse('{"key": 1}')
+        assert store.units[0].target == 1
+        store.units[0].target = 2
+
+        assert (
+            bytes(store).decode()
+            == """{
+    "key": 2
+}
+"""
+        )
+        store.units[0].target = "two"
+
+        assert (
+            bytes(store).decode()
+            == """{
+    "key": "two"
+}
+"""
+        )
+
 
 class TestJSONNestedResourceStore(test_monolingual.TestMonolingualUnit):
     StoreClass = jsonl10n.JsonNestedFile
@@ -278,6 +348,10 @@ class TestJSONNestedResourceStore(test_monolingual.TestMonolingualUnit):
         store = self.StoreClass()
         store.parse(JSON_ARRAY)
 
+        assert store.units[0].source == "One"
+        assert store.units[0].getid() == ".key[0]"
+        assert store.units[1].getid() == ".key[1]"
+
         out = BytesIO()
         store.serialize(out)
 
