@@ -45,7 +45,6 @@ class YAMLUnit(base.DictUnit):
     """A YAML entry"""
 
     IdClass = YAMLUnitId
-    DefaultDict = dict
 
     def __init__(self, source=None, **kwargs):
         # Ensure we have ID (for serialization)
@@ -149,7 +148,8 @@ class YAMLFile(base.DictStore):
                     "Previous: %s" % (type(data), data, prev)
                 )
 
-    def preprocess(self, data):
+    @staticmethod
+    def preprocess(data):
         """Preprocess hook for child formats"""
         return data
 
